@@ -78,12 +78,11 @@ import com.openexchange.server.impl.DBPool;
 import com.openexchange.tools.iterator.SearchIterator;
 import com.openexchange.tools.iterator.SearchIteratorException;
 
-
 /**
  * FreeBusyResults
+ *
  * @author <a href="mailto:martin.kauss@open-xchange.org">Martin Kauss</a>
  */
-
 public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
     
     public final static int MAX_SHOW_USER_PARTICIPANTS = 5;
@@ -127,6 +126,8 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
     private final CalendarCollection recColl;
     
     private int readFolderId;
+
+    private String categories;
     
     private static final Log LOG = LogFactory.getLog(FreeBusyResults.class);
     
@@ -213,6 +214,7 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
                 pflag = rs.getInt(8);
                 owner = rs.getInt(9);
                 colorLabel = rs.getInt(17); // SQL NULL would return zero which is no color label
+                categories = rs.getString(18); // SQL NULL would return null
                 cdao.setCreatedBy(owner);
                 final int recid = rs.getInt(10);
                 if (recid != 0) {
@@ -256,7 +258,7 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
             throw new OXCalendarException(OXCalendarException.Code.CALENDAR_SQL_ERROR, sqle);
         } catch(final Exception e) {
             LOG.error("FreeBusyResults calculation problem with oid "+oid+" / "+cdao == null ? "" : cdao.toString() , e);
-            throw new SearchIteratorException(SearchIteratorException.SearchIteratorCode.CALCULATION_ERROR, com.openexchange.groupware.EnumComponent.APPOINTMENT, oid, e);
+            throw new SearchIteratorException(SearchIteratorException.Code.CALCULATION_ERROR, com.openexchange.groupware.EnumComponent.APPOINTMENT, oid, e);
         }
         if (ft != 0 && cdao != null) {
             cdao.setFullTime(true);
@@ -308,10 +310,11 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
 
     private void fillDetails(final CalendarDataObject cdao) throws OXException {
         if (show_details) {
-            if(checkPermissions()) {
+            if (checkPermissions()) {                
                 cdao.setTitle(title);
                 cdao.setParentFolderID(readFolderId);
                 cdao.setLabel(colorLabel);
+                cdao.setCategories(categories);
             }
             final Participants ret = resolveConflictingUserParticipants();
             cdao.setParticipants(ret.getList());
@@ -405,9 +408,8 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
     }
     
     private final void preFillPermissionArray(final int groups[], final UserConfiguration uc) throws OXException {
-        final Connection readcon = null;
         try {
-            cfo = recColl.getAllVisibleAndReadableFolderObject(uid, groups, c, uc, readcon);
+            cfo = recColl.getAllVisibleAndReadableFolderObject(uid, groups, c, uc);
         } catch (final OXException ex) {
             throw new OXException(ex);
         } catch (final DBPoolingException ex) {
@@ -416,10 +418,6 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
             throw new OXException(ex);
         } catch (final SQLException ex) {
             throw new OXCalendarException(OXCalendarException.Code.CALENDAR_SQL_ERROR, ex);
-        } finally {
-            if (readcon != null) {
-                DBPool.closeReaderSilent(c, readcon);
-            }
         }
     }
     
@@ -502,32 +500,32 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
         try {
             
 
-            ResultSet rs = private_folder_information.executeQuery();
-            while (rs.next()) {
-                object_id = rs.getInt(1);
-                pfid = rs.getInt(2);
-                uid = rs.getInt(3);
-                if (!rs.wasNull()) {
+            ResultSet result = private_folder_information.executeQuery();
+            while (result.next()) {
+                object_id = result.getInt(1);
+                pfid = result.getInt(2);
+                uid = result.getInt(3);
+                if (!result.wasNull()) {
                     final PrivateFolderInformationObject pfio = new PrivateFolderInformationObject(object_id, pfid, uid);
                     list.add(pfio);
                 }
             }
-            rs.close();
+            result.close();
             // Add shared folders and check if there are such shared folders
             if (! cfo.getSharedFolderList().isEmpty()) {
                 shared_folder_info = calendarsqlimp.getSharedAppointmentFolderQuery(c, cfo, con);
     
-                rs = shared_folder_info.executeQuery();
-                while (rs.next()) {
-                    object_id = rs.getInt(1);
-                    pfid = rs.getInt(2);
-                    uid = rs.getInt(3);
-                    if (!rs.wasNull()) {
+                result = shared_folder_info.executeQuery();
+                while (result.next()) {
+                    object_id = result.getInt(1);
+                    pfid = result.getInt(2);
+                    uid = result.getInt(3);
+                    if (!result.wasNull()) {
                         final PrivateFolderInformationObject pfio = new PrivateFolderInformationObject(object_id, pfid, uid);
                         list.add(pfio);
                     }
                 }
-                rs.close();
+                result.close();
             }
         } catch(final SQLException sqle) {
             LOG.error(sqle.getMessage(), sqle);
